#
# spec file for package gtkspell3
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gtkspell3
Version:        3.0.10
Release:        3.12
Summary:        GTK3 Spell Checker Interface Library
License:        GPL-2.0-or-later
Group:          System/Libraries
URL:            http://gtkspell.sf.net/
Source:         https://sourceforge.net/projects/gtkspell/files/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(enchant-2)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.30.0
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(pango) >= 1.3.5
BuildRequires:  pkgconfig(vapigen)

%description
GtkSpell provides MSWord-style and MacOSX-style highlighting of
misspelled words in a GtkTextView widget. Right-clicking a misspelled
word opens a menu of suggested replacements.

%package -n libgtkspell3-3-0
Summary:        GTK3 Spell Checker Interface Library
Group:          System/Libraries
# Needed to make lang package installable
Provides:       gtkspell3 = %{version}

%description -n libgtkspell3-3-0
GtkSpell provides MSWord-style and MacOSX-style highlighting of
misspelled words in a GtkTextView widget. Right-clicking a misspelled
word opens a menu of suggested replacements.

%package -n typelib-1_0-GtkSpell-3_0
Summary:        GTK3 Spell Checker Interface Library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GtkSpell-3_0
GtkSpell provides MSWord-style and MacOSX-style highlighting of
misspelled words in a GtkTextView widget. Right-clicking a misspelled
word opens a menu of suggested replacements.

%package devel
Summary:        GTK3 Spell Checker Interface Library -- Development Files
Group:          Development/Libraries/X11
Requires:       libgtkspell3-3-0 = %{version}
Requires:       typelib-1_0-GtkSpell-3_0 = %{version}

%description devel
GtkSpell provides MSWord-style and MacOSX-style highlighting of
misspelled words in a GtkTextView widget. Right-clicking a misspelled
word opens a menu of suggested replacements.

%lang_package

%prep
%setup -q

%build
%configure \
	--disable-static \
	--enable-vala
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}

%post -n libgtkspell3-3-0 -p /sbin/ldconfig
%postun -n libgtkspell3-3-0 -p /sbin/ldconfig

%files -n libgtkspell3-3-0
%license COPYING
%doc AUTHORS ChangeLog README
%{_libdir}/libgtkspell3-3.so.*

%files -n typelib-1_0-GtkSpell-3_0
%{_libdir}/girepository-1.0/GtkSpell-3.0.typelib

%files devel
%{_datadir}/gir-1.0/GtkSpell-3.0.gir
%{_includedir}/gtkspell-3.0/
%{_libdir}/libgtkspell3-3.so
%{_libdir}/pkgconfig/gtkspell3-3.0.pc
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gtkspell3-3.0.deps
%{_datadir}/vala/vapi/gtkspell3-3.0.vapi
%doc %{_datadir}/gtk-doc/html/gtkspell3/

%files lang -f %{name}.lang

%changelog
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sat Nov 17 2018 bjorn.lie@gmail.com
- Update to version 3.0.10:
  + Port to enchant-2.
  + Updated translations.
- Replace pkgconfig(enchant) with pkgconfig(enchant-2) following
  upstreams port.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat May 20 2017 avvissu@yandex.by
- Add pkgconfig(vapigen) BuildRequires and pass --enable-vala to
  configure call: Build vala bindings.
* Sat Nov  5 2016 malcolmlewis@opensuse.org
- Update to version 3.0.9:
  + Add gtk_spell_checker_add_to_dictionary.
  + Add gtk_spell_checker_ignore_word.
  + Fix possible use-after-free in
    gtk_spell_checker_decode_language_code.
- Change source compression to tar.xz.
* Thu May 19 2016 tyang@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue May  3 2016 zaitor@opensuse.org
- Update to version 3.0.8:
  + Fix cases where check_word is called on an empty range.
  + Add gtk_spell_checker_check_word.
  + Add gtk_spell_checker_get_suggestions.
  + Updated translations.
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.0.6:
  + Fix badly merged translations.
  + Also recognize U+2019 as apostrophe.
  + Updated translations.
- Changes from version 3.0.5:
  + Fix incorrect handling of single quotes.
  + Buildsystem cleanups and tweaks.
  + Updated translations.
- Changes from version 3.0.4:
  + Make decode-language-codes more robust.
  + Don't use deprecated symbols when compiled against gtk3 >= 3.9.
  + Updated translations.
* Mon Jun 24 2013 dimstar@opensuse.org
- Update to version 3.0.3:
  + Add decode-language-codes property (to show more friendly
    dictionary names in the context menu), implemented using
    iso-codes.
  + Add gtk_spell_checker_decode_language_code method.
  + Use g_win32_get_package_installation_directory_of_module on
    win32.
  + Add -no-undefined when building on for win32.
  + Use $(foo) instead of @foo@ in Makefiles.
  + Fix GTK_SPELL_CFLAGS -> GTK_SPELL3_CFLAGS typo.
  + Updated translations.
- Changes from version 3.0.2:
  + Added vala bindings.
  + Added some documentation on language bindings.
- Add pkgconfig(gobject-introspection-1.0) BuildRequires: needed in
  order to get the typelib language bindings.
- Split out typelib-1_0-GtkSpell-3_0 subpackage.
* Sun Mar  3 2013 zaitor@opensuse.org
- Update to version 3.0.1:
  + Actually declare GtkSpellChecker as a G_TYPE_INITIALLY_UNOWNED.
  + Really silently exit if detach is called when not attached.
  + Add gtk_spell_error_get_type.
  + Use PIMPL idiom for private members of GtkSpellChecker.
  + Update license file with correct FSF address, add license
    headers to files.
- Changes from version 3.0.0:
  + New major version not API or ABI compatible with gtkspell 2.x.
  + Add GTK+ 3 Support (required by default).
  + A GTK+ 2 compatible version can be built using --enable-gtk2.
  + Update to be GObject based.
  + Add introspection support.
  + Add "language-changed" signal.
  + Add gtk_spell_checker_get_language function.
  + Updated translations.
- Rename libgtkspell-3-0 into libgtkspell3-3-0, following upstream.
- gtkspell3-devel now provides pkgconfig(gtkspell3-3.0), so some
  fallout in other packages are to be expexted.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Tue Oct 11 2011 vuntz@opensuse.org
- Pass %%{?no_lang_C} to %%find_lang to avoid packaging any potential
  english documentation in lang subpackage.
* Mon Sep 26 2011 vuntz@opensuse.org
- Cleanup for inclusion in Factory.
* Sun Aug 28 2011 gankov@opensuse.org
- Initial package for gtkspell3, the GTK+ 3 version of gtkspell.
- Note that the tarball is actually a pre-release.
